Load a texture from the local filesystem.

- When not using pipeline resources the texture informations are returned directly.
- When using pipeline resources the texture informations can be retrieved from the [PipelineResources] object.